++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
		       PDB_EXTRACT  HELP
     FOR FAST COLLECTING COMPLETE STRUCTURE INFORMATION FOR DEPOSITION
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
You can either use the on-line tool (http://pdb-extract.rutgers.edu/) or the
following one of the two Unix options:

Option 1: The Unix script method (easier)
Option 2: The full Unix command method (allows greater flexibility of options)

==================================Option 1==================================

STEP 1: Generate the data template file (called data_template.text) and the  
        script input file (called log_script.inp) using the command:

     extract  -pdb  coordinate_PDB_file   (if PDB format)
or
     extract  -cif  coordinate_CIF_file   (if mmCIF format) 

        The file data_template.text contains data entries for the sequence 
        of each unique polymer present in the structure. It also contains
	fields for entering other non-electronically captured information 
        like the author name(s), citation(s), etc.
 
        The file log_script.inp has fields for entering the names of logfiles 
        obtained from different crystallographic applications which were used 
	for the structure determination. Relevant data from these log files 
	are extracted by pdb_extract for the deposition. 

First, complete the data entry fields of the ASCII file 'data_template.text' 
Second, complete the data entry fields of the ASCII file 'log_script.inp'

STEP 2: Run the program:

     extract  -ext  log_script.inp

	This will produce two mmCIF files, one for all the structure 
	factors (output_sf.cif) and the other for the coordinates and 
	all the statistics from steps of structure solution (output.cif).

STEP 3: Validation and deposition:
     
        It is recommended to upload the two files (output.cif  and
        output_sf.cif) to ADIT (http://rcsb-deposit.rutgers.edu/adit/)
	for validation and direct deposition.

        However, it is also OK to validate the structure locally by the 
        command: 

validation-v8 -f output.cif -o 2 -public -exchange -adit
maxit-v8.01-O -i output.cif -o 8 -exchange_in -exchange_out -keep_contact_author

	The first command generates a validation report while the second
	command prepares the file for deposition. You can deposit the resulting 
	file output.cif.cif (after running the second command) and output_sf.cif 
	(generated in step 2) either directly using ADIT or send these files to 
	'deposit@rcsb.rutgers.edu' for deposition.


==================================Option 2==================================

STEP 1: Generate the data template file (data_template.text) using the command:

     extract  -pdb  coordinate_PDB_file   (if PDB format)
or
     extract  -cif  coordinate_CIF_file   (if mmCIF format) 

	The file data_template.text is identical to that generated in option 1.

STEP 2: Run pdb_extract
     
	In this option, the names of logfiles from different crystallographic 
	applications are entered directly in the command line. See example.
 
Example 1. Data deposition for a molecular replacement (MR) experiment:
   	(Structure solution details: data scaling by HKL (one structure factor 
   	data set), MR by AMORE, refinement by REFMAC5)

   	FILES NEEDED FOR COMPLETING DEPOSITION:
   	* one LOG file generated from scaling by HKL: scaleui.log  (one data set).
   	* two LOG files from AMORE(rotation and translation): tran.log, rot.log
   	* two files from REFMAC5: native.refmac(mmCIF format),and 
                                  refmac1.pdb (PDB format)
	* data_template.text: contains non-electronically captured information.

Run the program using the following command:

pdb_extract    -e  MR \
               -m  AMORE -iLOG tran.log rot.log \
               -r  REFMAC5 -iCIF native.refmac -iPDB refmac1.pdb \
               -s  HKL -iLOG scaleui.log \
            -iENT  data_template.text \
               -o  output.cif

	All information about the structure is in the resulting output.cif file

	Since in this example, there is only one structure factor data set and 
	REFMAC5 was used for refinement, the mtz format structure factor file 
	can be converted to a mmCIF file using the application mtz2various 
	provided by CCP4. 

Example 2. Data deposition for MAD experiment:
   	 STRUCTURE SOLUTION DETAILS: 
        * data scaling and indexing by HKL: generated five LOG files
        (one indexing LOG file 'index.log', one scaling LOG file for
   	refinement 'native.log' and three scaling LOG files for phasing
        'cale1.log scale2.log scale3.log')

        * phasing by SOLVE: generated one LOG file 'solve.prt'
        * density modification by RESOLVE: generated one LOG file 'resolve.log'
        * final refinement by CNS: generated one mmCIF file 'cns_deposit.cif'
                                 or a PDB file
   	* data_template.text: generated by 'extract -cif(or -pdb) file_name.
                   It contains non-electronically captured information.

        The reflection data is   reflect.cv (for refinement)
        scale1.sca, scale2.sca, scale3.sca  (for MAD phasing)


TO GET COMPLETE MMCIF FILE,  RUN THE PROGRAM USING THE FOLLOWING COMMANDS:
pdb_extract    -e  MAD \
               -p  SOLVE -iLOG solve.prt \
               -d  RESOLVE -iLOG resolve.log \
               -r  CNS -icif cns_deposit.cif \
               -i  HKL -iLOG index.log \                (data set for refinement)
               -s  HKL -iLOG native.log \                (data set for refinement)
               -sp HKL scale1.log scale2.log scale3.log \ (for phasing)
             -iENT data_template.text \
               -o  output.cif


TO GET COMPLETE STRUCTURE FACTOR FILE, RUN THE PROGRAM USING THE FOLLOWING COMMANDS:

pdb_extract_sf -rt F -rp CNS -idat reflect.cv \           (for refinement)
               -dt I -dp HKL \                            (for phasing)
               -c  1 -w 1 -idat  scale1.sca \
               -c  1 -w 2 -idat  scale2.sca \
               -c  1 -w 3 -idat  scale3.sca \
               -o  output_sf.cif


	NOTE: For CNS user, you can either use the mmCIF format (generated
        by deposit_mmcif.inp script) or you can use the PDB file for extract
        and pdb_extract. Both should be consistent!

	The arguments and input file names may be continued on the next line
	of the script or command line using a back-slash (\) at the end of 
	that line, but no space is allowed after (\). 

STEP 3: Validation and deposition:
     The same as option 1

============================================================================
Commonly used arguments for program pdb_extract (for structural information)

 
OPTIONS:
   -o  output file name given by user (default: pdb_extract.mmcif)
   -e  experimental methods [MR|SAD|MAD|SIR|SIRAS|MIR|MIRAS]
   -i  software for indexing/integration [HKL|DENZO|DTREK|MOSFLM] 
   -s  software for data scaling (refinement) [SCALA|HKL|SCALEPACK|DTREK|SAINT|3DSCALE]
  -sp  software for data scaling (phasing) [SCALA|HKL|SCALEPACK|DTREK|SAINT|3DSCALE]
   -p  software for phasing [CNS|XPLOR|MLPHARE|SOLVE|SHELX|SNB|BnP|SHARP|PHASES|WARP]
   -m  software for molecular replacement [AMORE|CNS|XPLOR|XPLOR|EPMR|MOLREP|PHASER]
   -d  software for density modification [CNS|XPLOR|DM|RESOLVE|SOLOMON|SHELXE|SHARP]
   -r  software for refinement [CNS|XPLOR|REFMAC5|SHELX|TNT|PROLSQ|NUCLSQ|RESTRAIN]
-iLOG  Followed by LOG file generated from the above software
-iPDB  Followed by PDB file generated from the above software
-iCIF  Followed by mmCIF file generated from the above software
-iENT  Followed by data_template.text generated by 'extract -pdb pdb_fil_name'
       or followed by any other self_defined mmCIF file containing complete sequences 
-iDAT  Followed by reflection data file to generate I/sigmaI, when it is not 
       in the LOG file of data scaling (e.g. HKL).

----------------------------------------
Commonly used arguments for program pdb_extract_sf (for structure factors only)

usage:    pdb_extract_sf [OPTION]... [FILE]...

	OPTIONS:
	-o followed by the given output file name
       -dt followed by data type I or F (data used for phasing)
       -dp followed by software (HKL|SCALEPACK|DTREK|SAINT|SCALA|3DSCALE|OTHER )
	-c followed by crystal number (like -c 1 )
 	-w followed by wavelength number (like -w 1)

       -rt followed by data type I or F (used for final refinement)
       -rp followed by reflection data format used for final refinement
     	   (CNS|TNT|SHELX|HKL|SCALEPACK|DTREK|SAINT|SCALA|3DSCALE|OTHER)
     -iDAT followed by a file name containing reflection data.
           (Format corresponds to the specific program used)
    - iCIF followed by a file name with mmCIF format 

	Notes: 
        -rt and -rp are used for refinement.
        -dt, -fp, -c, and -w are used for phasing.
===================================END======================================